IssueType

Enum IssueType 

pub enum IssueType {
Show 13 variants GlobalComplexity, CascadingChangeRisk, InappropriateIntimacy, HighEfferentCoupling, HighAfferentCoupling, UnnecessaryAbstraction, CircularDependency, ShallowModule, PassThroughMethod, HighCognitiveLoad, GodModule, PublicFieldExposure, PrimitiveObsession,
}
Types of coupling problems

Variants



GlobalComplexity

Strong coupling spanning a long distance



CascadingChangeRisk

Strong coupling to a frequently changing component



InappropriateIntimacy

Intrusive coupling across boundaries (field/internals access)



HighEfferentCoupling

A module with too many dependencies



HighAfferentCoupling

A module that too many others depend on



UnnecessaryAbstraction

Weak coupling where stronger might be appropriate



CircularDependency

Circular dependency detected



ShallowModule

Module with interface complexity close to implementation complexity



PassThroughMethod

Method that only delegates to another method without adding value



HighCognitiveLoad

Module requiring too much knowledge to understand/modify



GodModule

Module with too many functions, types, or implementations



PublicFieldExposure

Public fields exposed to external modules (should use getters/methods)



PrimitiveObsession

Functions with too many primitive parameters (consider newtype)

Implementations

Source

impl IssueType

pub fn description(&self) -> &'static str

Get a detailed description of what this issue type means