pub struct BaselineDiff {
pub new_issues: Vec<CouplingIssue>,
pub resolved_issues: Vec<CouplingIssue>,
pub unchanged: usize,
pub score_delta: f64,
pub baseline_grade: HealthGrade,
pub current_grade: HealthGrade,
}Expand description
Difference between a baseline report and the current report.
Fields
new_issues: Vec<CouplingIssue>Issues present only in the current report.
resolved_issues: Vec<CouplingIssue>Issues present only in the baseline report.
unchanged: usizeNumber of stable issue keys present in both reports.
score_delta: f64Current average score minus baseline average score.
baseline_grade: HealthGradeBaseline health grade.
current_grade: HealthGradeCurrent health grade.
Implementations
Sourceimpl BaselineDiff
impl BaselineDiff
Sourcepub fn ratchet_failures(&self, severity: Severity) -> Vec<&CouplingIssue>
pub fn ratchet_failures(&self, severity: Severity) -> Vec<&CouplingIssue>
New issues at or above severity.