Module volatility

Module volatility 

Git history analysis for volatility measurement

Analyzes git log to determine how frequently files change. Optimized for large repositories using streaming and git path filtering.

Structs

TemporalCoupling
Temporal coupling between two files (co-change pattern)
VolatilityAnalyzer
Volatility analyzer using git history
VolatilityStats
Statistics about volatility across the project

Enums

Volatility
Volatility levels (how often a component changes)
VolatilityError
Errors that can occur during volatility analysis